function sxt_imgtypes,index,al,dg,hr,qr,hrdg,qrdg,$
	hral,qral,mnth=mnth,yr=yr

;+
; CALLING EXAMPLE
;	ff=sxt_imgtypes(index,al,dg,hr,qr,mnth='feb',yr=00)
; PURPOSE
;	Given an index or roadmap structure, return the indices
;	of the Al.1, AlMg, HR(AlMg) and QR(AlMg) exposures.  
;	Specification of month or year will limit the return
;	to those periods.
; INPUT
;	index, SXT index or roadmap structure
; OPTIONAL KEYWORD INPUT
;	mnth, 3-letter string specifying month (e.g., mnth='apr')
;		or
;             month number (1-12) 	
;	yr, 2 character year specification (e.g., yr=00)
; OUTPUT
;	ff is a list of indices for the given month
;	al are the sub-indices for all Al.1 images.
;	dg are the sub-indices for all AlMg images
;	hr are the sub-indices for all HR images
;	qr are the sub-indices for all QR images
;	hrdg are the sub-indices for the HR AlMg images
;	qrdg are the sub-indices for the QR AlMg images
;	hral are the sub-indices for the HR Al.1 images
;	qral are the sub-indices for the QR Al.1 images
; HISTORY
;	8-Mar-2004, LWA
;      21-Apr-2004, LWA  Changed name from get_month.pro
;			 Added hrdg and qrdg variables
;      22-Apr-2004, lwa  For generality, added hral and qral.
;-

if NOT keyword_set(mnth) then begin
   mm = lindgen(n_elements(index))
   goto,skipover
endif
if datatype(mnth,2) ne 7 then begin
   case 1 of
      mnth eq 1 : mnth  = 'jan'
      mnth eq 2 : mnth  = 'feb'
      mnth eq 3 : mnth  = 'mar'
      mnth eq 4 : mnth  = 'apr'
      mnth eq 5 : mnth  = 'may'
      mnth eq 6 : mnth  = 'jun'
      mnth eq 7 : mnth  = 'jul'
      mnth eq 8 : mnth  = 'aug'
      mnth eq 9 : mnth  = 'sep'
      mnth eq 10 : mnth = 'oct'
      mnth eq 11 : mnth = 'nov'
      mnth eq 12 : mnth = 'dec'
   endcase
endif

case 1 of
   mnth eq 'jan' : nxt='feb'
   mnth eq 'feb' : nxt='mar'
   mnth eq 'mar' : nxt='apr'
   mnth eq 'apr' : nxt='may'
   mnth eq 'may' : nxt='jun'
   mnth eq 'jun' : nxt='jul'
   mnth eq 'jul' : nxt='aug'
   mnth eq 'aug' : nxt='sep'
   mnth eq 'sep' : nxt='oct'
   mnth eq 'oct' : nxt='nov'
   mnth eq 'nov' : nxt='dec'
   mnth eq 'dec' : nxt='jan'
endcase
if nxt eq 'jan' then nxtyr=yr+1 else nxtyr=yr

mm=sel_timrange(index,'1-'+strtrim(mnth,2)+'-'+strtrim(yr,2),$
   '1-'+nxt+'-'+strtrim(nxtyr,2),/between)
SKIPOVER:
al=where(gt_filtb(index(mm)) eq 2)
dg=where(gt_filtb(index(mm)) eq 3)
hr=where(gt_res(index(mm),/orig) eq 1)
qr=where(gt_res(index(mm),/orig) eq 2)
hrdg=where(gt_filtb(index(mm)) eq 3 and gt_res(index(mm),/orig) eq 1)
qrdg=where(gt_filtb(index(mm)) eq 3 and gt_res(index(mm),/orig) eq 2)
hral=where(gt_filtb(index(mm)) eq 2 and gt_res(index(mm),/orig) eq 1)
qral=where(gt_filtb(index(mm)) eq 2 and gt_res(index(mm),/orig) eq 2)

return,mm
end

